StyleContext class

Constructors

StyleContext()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

animated({Duration delay = Duration.zero, Duration duration = const Duration(milliseconds: 500), Curve curve = Curves.easeInOut}) → StyleContext
backgroundColor(Color color) → StyleContext
borderRadius(double radius) → StyleContext
boxShadow(BoxShadow shadow) → StyleContext
collapseX(bool value) → StyleContext
collapseY(bool value) → StyleContext
fontFamily(String family) → StyleContext
fontSize(double size) → StyleContext
fontWeight(FontWeight weight) → StyleContext
foregroundColor(Color color) → StyleContext
iconSize(double size) → StyleContext
margin({double s = 0, double t = 0, double e = 0, double b = 0}) → StyleContext
marginAll([double value = 10]) → StyleContext
marginLTRB({double l = 0, double t = 0, double r = 0, double b = 0}) → StyleContext
marginXY({double x = 0, double y = 0}) → StyleContext
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
opacity(double x) → StyleContext
padding({double s = 0, double t = 0, double e = 0, double b = 0}) → StyleContext
paddingAll([double value = 10]) → StyleContext
paddingLTRB({double l = 0, double t = 0, double r = 0, double b = 0}) → StyleContext
paddingXY({double x = 0, double y = 0}) → StyleContext
rotate(double degrees) → StyleContext
rotateAlignment(AlignmentGeometry x) → StyleContext
rotateRadians(double radians) → StyleContext
textStyle(TextStyle style) → StyleContext
toString() → String
A string representation of this object.
inherited
translate({double x = 0, double y = 0}) → StyleContext

Operators

operator ==(Object other) → bool
The equality operator.
inherited